import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.core._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/aws-cloudfront-s3",
    "1.61.1",
    __name__[0:-6],
    "aws-cloudfront-s3@1.61.1.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
